import React from 'react';
import ReactDOM from 'react-dom';
import AdainTree, {toggleExpandedForAll} from 'react-adain-tree';
import { MdAssignment, MdFlashOn, MdContentCopy, MdDelete, MdVerticalAlignTop, MdVerticalAlignBottom } from 'react-icons/lib/md';

class App extends React.Component {
	constructor(props) {
		super(props);

		this.state = {
			searchString: '',
			searchFocusIndex: 0,
			searchFoundCount: null,
			treeData: [
				{_id: 'a', expanded: true, name: 'A', hasCheckBox: true, isFolder: true, children:[
					{_id: 'aa', expanded: true, name: 'AA', assignedUserName: 'mgkim'}, {_id: 'ab', name: 'AB', assignedUserName: 'syjang'}, {_id: 'ac', name: 'AC', isFolder: true, children: [
						{_id: 'aca', name: 'ACA', assignedUserName: 'mgkim'}, {name: 'ACB', assignedUserName: 'mgkim'}, {name: 'ACC', assignedUserName: 'mgkim'}
					]}
				]},
				{_id: 'b', name: 'B', assignedUserName: 'mgkim'},
				{_id: 'c', name: 'C', isFolder: true, children:[
					{_id: 'ca', name: 'CA', assignedUserName: 'mgkim'}, {_id: 'cb', title: 'CB', assignedUserName: 'mgkim'}
				]}
			]
		};

		this.updateTreeData = this.updateTreeData.bind(this);
		this.search = this.search.bind(this);
		this.expandAll = this.expandAll.bind(this);
		this.collapseAll = this.collapseAll.bind(this);
		this.onClickNodeName = this.onClickNodeName.bind(this);
		this.onClickCopy = this.onClickCopy.bind(this);
		this.onClickDelete = this.onClickDelete.bind(this);

		this.onRowClick = this.onRowClick.bind(this);
	}
	updateTreeData(treeData) {
		this.setState({ treeData });
	}

	expand(expanded) {
		this.setState({
			treeData: toggleExpandedForAll({
				treeData: this.state.treeData,
				expanded,
			}),
		});
	}

	expandAll() {
		this.expand(true);
	}

	collapseAll() {
		this.expand(false);
	}

	search() {
		console.log(this.refs.txtSearch.value);
	}

	render () {
		const {
			treeData,
			searchString,
			searchFocusIndex,
			searchFoundCount,
		} = this.state;

		return (
			<div>
				<div>
					<form
						style={{ display: 'inline-block' }}
						onSubmit={event => {
							event.preventDefault();
						}}
					>
						<label htmlFor="find-box">
							Search:&nbsp;

							<input
								id="find-box"
								type="text"
								value={searchString}
								onChange={event => this.setState({ searchString: event.target.value })}
							/>
						</label>
					</form>
				</div>
				<AdainTree childPropertyName="children"
									 titleField="name"
									 commonSetting={
										 {
											 hasCheckBoxAll: true
										 }
									 }
									 divHeight="350"
									 rowHeight={49}
									 scaffoldBlockPxWidth={30}
									 header={[
										 {field: 'name', title: 'TITLE'}
									 ]}
									 treeData={treeData}
									 onChange={this.updateTreeData}
									 onRowClick={this.onRowClick}
									 onMoveNode={({ node, treeIndex, path }) =>
										 console.debug(
											 'node:', node,
											 'treeIndex:', treeIndex,
											 'path:', path
										 )}
									 canDrag={({ node }) => !node.noDragging}
									 canDrop={({ nextParent }) =>
									 !nextParent || !nextParent.noChildren}
									 searchQuery={searchString}
									 searchFocusOffset={searchFocusIndex}
									 searchFinishCallback={matches =>
										 this.setState({
											 searchFoundCount: matches.length,
											 searchFocusIndex: matches.length > 0
												 ? searchFocusIndex % matches.length
												 : 0,
										 })}
									 generateNodeProps={(rowInfo)=>{
										 if(rowInfo.node.children){
											 return ({buttons: [
												 <button
													 className="btnNodeNameblank"
												 >
													 &nbsp;
												 </button>,
												 <button
													 className="btnNodeBlank"
												 >
													 &nbsp;
												 </button>,
												 <button
													 className="btnNodeBlank"
												 >
													 &nbsp;
												 </button>,
												 <button
													 className="btnNodeCopy"
													 title="Copy"
													 onClick={() => this.onClickCopy(rowInfo)}
												 >
													 <MdContentCopy />
												 </button>,
												 <button
													 className="btnNodeDelete"
													 title="Delete"
													 onClick={() => this.onClickDelete(rowInfo)}
												 >
													 <MdDelete />
												 </button>
											 ]});
										 }else{
											 return ({
												 buttons: [
													 <button
														 className="btnNodeName"
														 style={{
															 verticalAlign: 'middle',
														 }}
														 onClick={() => this.onClickNodeName(rowInfo)}
														 title="Name"
													 >
														 {rowInfo.node.assignedUserName}
													 </button>,
													 <button
														 className="btnNodeAssignment disabled"
														 title="Assign"
													 >
														 <MdAssignment />
													 </button>,
													 <button
														 className="btnNodeFlashOn disabled"
														 title="FlashOn"
													 >
														 <MdFlashOn />
													 </button>,
													 <button
														 className="btnNodeCopy"
														 title="Copy"
														 onClick={() => this.onClickCopy(rowInfo)}
													 >
														 <MdContentCopy />
													 </button>,
													 <button
														 className="btnNodeDelete"
														 title="Delete"
														 onClick={() => this.onClickDelete(rowInfo)}
													 >
														 <MdDelete />
													 </button>
												 ],
											 });
										 }
									 }}
									 type="static"  // static | dynamic
				/>
			</div>
		);
	}

	onRowClick({node, path, treeIndex}) {
		console.log('on click row', node, path, treeIndex);
	}

	onClickNodeName({ node, path, treeIndex }) {
		console.log('on click node name', node, path, treeIndex);
	}

	onClickCopy({node, path, treeIndex}) {
		console.log('on click copy', node, path, treeIndex);
	}

	onClickDelete({node, path, treeIndex}) {
		console.log('on click delete', node, path, treeIndex);
	}
}

ReactDOM.render(<App />, document.getElementById('app'));
